@@ -1,5 +1,5 @@
 /*
-//@line 42 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 42 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
 */
 
 /* This file implements the nsIHelperAppLauncherDialog interface.
@@ -99,9 +99,9 @@ nsUnknownContentTypeDialog.prototype = {
           if (aFolderType != "Downloads")
             throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
         
-//@line 147 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 147 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           return "Home";
-//@line 150 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 150 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
         }
         
         function getDownloadsFolder(aFolder)
@@ -356,7 +356,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files. 
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 424 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 424 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       var mimeType = this.mLauncher.MIMEInfo.MIMEType;
       if (mimeType == "application/octet-stream" || 
           mimeType == "application/x-msdownload" ||
@@ -386,12 +386,9 @@ nsUnknownContentTypeDialog.prototype = {
     
     _timer: null,
     notify: function (aTimer) {
-      try { // The user may have already canceled the dialog.
-        if (!this._blurred)
-          this.mDialog.document.documentElement.getButton('accept').disabled = false;
-      } catch (ex) {}
+      if (!this._blurred)
+        this.mDialog.document.documentElement.getButton('accept').disabled = false;
       this._delayExpired = true;
-      this._timer = null; // the timer won't release us, so we have to release it
     },
     
     postShowCallback: function () {
@@ -491,12 +488,12 @@ nsUnknownContentTypeDialog.prototype = {
         var result;
 
         // The checking is different on Windows...
-//@line 572 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 569 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
             // On other platforms, default is Ok if there is a default app.
             // Note that nsIMIMEInfo providers need to ensure that this holds true
             // on each platform.
         return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 577 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 574 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
     
     // Set "default" application description field.
@@ -517,9 +514,9 @@ nsUnknownContentTypeDialog.prototype = {
 
     // getPath:
     getPath: function (aFile) {
-//@line 600 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 597 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       return aFile.path;
-//@line 602 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 599 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
 
     // initAppAndSaveToDiskValues:
@@ -587,9 +584,9 @@ nsUnknownContentTypeDialog.prototype = {
       }
       
       // otherHandler is always disabled on Mac
-//@line 673 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 670 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       otherHandler.nextSibling.hidden = otherHandler.nextSibling.nextSibling.hidden = false;
-//@line 675 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 672 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       this.updateOKButton();
     },
 
@@ -742,7 +739,7 @@ nsUnknownContentTypeDialog.prototype = {
           // for the file to be saved to to pass to |saveToDisk| - otherwise
           // we must ask the user to pick a save name.
 
-//@line 841 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 838 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           this.mLauncher.saveToDisk(null, false);
         }
         else
