@@ -1,4 +1,4 @@
-//@line 42 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 41 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -20,11 +20,7 @@ var gActiveDownloads  = [];
 // opened by the xpinstall manager prevents the window from being closed after
 // each download completes (because xpinstall downloads are done sequentially, 
 // not concurrently) 
-var gCanAutoClose   = true;
-
-// If the user has interacted with the window in a significant way, we should
-// not auto-close the window. Tough UI decisions about what is "significant."
-var gUserInteracted = false;
+var gCanAutoClose     = true;
 
 ///////////////////////////////////////////////////////////////////////////////
 // Utility Functions 
@@ -147,12 +143,14 @@ function autoClose(aDownload)
     // For the moment, just use the simple heuristic that if this window was
     // opened by the download process, rather than by the user, it should auto-close
     // if the pref is set that way. If the user opened it themselves, it should
-    // not close until they explicitly close it.
+    // not close until they explicitly close it. 
+    // We may like to revisit this in a bit more detail later, perhaps we want
+    // to keep it up if the user messes with it in a significant way.
     var pref = Components.classes["@mozilla.org/preferences-service;1"]
                         .getService(Components.interfaces.nsIPrefBranch);
     var autoClose = pref.getBoolPref(PREF_BDM_CLOSEWHENDONE)
     if (autoClose && (!window.opener || window.opener.location.href == window.location.href) &&
-        gCanAutoClose && !gUserInteracted)
+        gCanAutoClose)
       gCloseDownloadManager();
   }
 }
@@ -385,7 +383,6 @@ function onDownloadOpenWith(aEvent)
 
 function onDownloadProperties(aEvent)
 {
-  gUserInteracted = true;
   window.openDialog("chrome://mozapps/content/downloads/downloadProperties.xul",
                     "_blank", "modal,centerscreen,chrome,resizable=no", aEvent.target.id);
 }
@@ -752,7 +749,7 @@ function initAutoDownloadDisplay()
 
     function getSpecialFolderKey(aFolderType) 
     {
-//@line 807 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
+//@line 803 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/downloads/content/downloads.js"
       return "Home";
     }
     
