@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 37 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 
 ///////////////////////////////////////////////////////////////////////////////
 // Globals
@@ -9,6 +9,7 @@ const nsIUpdateItem = Components.interfaces.nsIUpdateItem;
 var gExtensionManager = null;
 var gExtensionsView   = null;
 var gWindowState      = "";
+var gGetMoreURL       = "";
 var gCurrentTheme     = "classic/1.0";
 var gDefaultTheme     = "classic/1.0";
 var gDownloadManager  = null;
@@ -49,7 +50,7 @@ function getIDFromResourceURI(aURI)
 
 function openURL(aURL)
 {
-//@line 89 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 90 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
   var uri = Components.classes["@mozilla.org/network/io-service;1"]
                       .getService(Components.interfaces.nsIIOService)
                       .newURI(aURL, null, null);
@@ -57,7 +58,7 @@ function openURL(aURL)
   var protocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
                               .getService(Components.interfaces.nsIExternalProtocolService);
   protocolSvc.loadUrl(uri);
-//@line 100 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 101 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
 }
 
 function flushDataSource()
@@ -113,8 +114,7 @@ function Startup()
   gExtensionsView = document.getElementById("extensionsView");
   gExtensionsView.setAttribute("state", gWindowState);
   gExtensionManager = Components.classes["@mozilla.org/extensions/manager;1"]
-                                .getService(Components.interfaces.nsIExtensionManager)
-                                .QueryInterface(Components.interfaces.nsIExtensionManager2);
+                                .getService(Components.interfaces.nsIExtensionManager);
   gApp = Components.classes["@mozilla.org/xre/app-info;1"].getService(Components.interfaces.nsIXULAppInfo)
                    .QueryInterface(Components.interfaces.nsIXULRuntime);
 
@@ -152,23 +152,18 @@ function Startup()
   document.title = extensionsStrings.getString(gWindowState + "Title");
   
   gExtensionsViewController.onCommandUpdate(); 
-
+  
+  gGetMoreURL = pref.getComplexValue(isExtensions ? PREF_EXTENSIONS_GETMOREEXTENSIONSURL 
+                                                  : PREF_EXTENSIONS_GETMORETHEMESURL, 
+                                     Components.interfaces.nsIPrefLocalizedString).data;
+  var app = Components.classes["@mozilla.org/xre/app-info;1"]
+                      .getService(Components.interfaces.nsIXULAppInfo);
+  gGetMoreURL = gGetMoreURL.replace(/%APPID%/g, app.ID);
+  // Update various pieces of state-dependant UI
   var getMore = document.getElementById("getMore");
-  try {
-    var getMoreURL = pref.getComplexValue(isExtensions ? PREF_EXTENSIONS_GETMOREEXTENSIONSURL 
-                                                       : PREF_EXTENSIONS_GETMORETHEMESURL, 
-                                          Components.interfaces.nsIPrefLocalizedString).data;
-    var app = Components.classes["@mozilla.org/xre/app-info;1"]
-                        .getService(Components.interfaces.nsIXULAppInfo);
-    getMoreURL = getMoreURL.replace(/%APPID%/g, app.ID);
-    // Update various pieces of state-dependant UI
-    getMore.setAttribute("value", getMore.getAttribute(isExtensions ? "valueextensions" : "valuethemes"));
-    getMore.setAttribute("tooltiptext", getMore.getAttribute(isExtensions ? "tooltiptextextensions" : "tooltiptextthemes"));
-    getMore.setAttribute('href', getMoreURL);
-  }
-  catch (e) {
-    getMore.hidden = true;
-  }
+  getMore.setAttribute("value", getMore.getAttribute(isExtensions ? "valueextensions" : "valuethemes"));
+  getMore.setAttribute("tooltiptext", getMore.getAttribute(isExtensions ? "tooltiptextextensions" : "tooltiptextthemes"));
+  getMore.setAttribute('href', gGetMoreURL);
   
   if (!isExtensions) {
     var themePreviewArea = document.getElementById("themePreviewArea");
@@ -205,9 +200,9 @@ function Startup()
   
   // Set the tooltips
   if (!isExtensions) {
-//@line 248 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 243 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     document.getElementById("installButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdInstallTooltipTheme"));
-//@line 250 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 245 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     document.getElementById("uninstallButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdUninstallTooltipTheme"));
     document.getElementById("updateButton").setAttribute("tooltiptext", extensionsStrings.getString("cmdUpdateTooltipTheme"));
   }
@@ -363,6 +358,11 @@ XPInstallDownloadManager.prototype = {
           ps.alert(window, title, message);
           element.setAttribute("status", msg);
         }
+        // Remove the dummy, since we installed successfully (only if we're a URL, 
+        // not a download operation on an existing item.
+        var type = gWindowState == "extensions" ? nsIUpdateItem.TYPE_EXTENSION
+                                                : nsIUpdateItem.TYPE_THEME;
+        gExtensionManager.removeDownload(aAddon.xpiURL);
         break;
       case nsIXPIProgressDialog.DIALOG_CLOSE:
         break;
@@ -592,13 +592,11 @@ function onThemeSelect(aEvent)
 ///////////////////////////////////////////////////////////////////////////////
 // View Context Menus
 var gExtensionContextMenus = ["menuitem_options", "menuitem_homepage", "menuitem_about", 
-                              "menuseparator_1", "menuitem_uninstall",
-                              "menuitem_cancelUninstall", "menuitem_update",
+                              "menuseparator_1", "menuitem_uninstall", "menuitem_update",
                               "menuitem_enable", "menuitem_disable", "menuseparator_2", 
                               "menuitem_moveTop", "menuitem_moveUp", "menuitem_moveDn"];
 var gThemeContextMenus = ["menuitem_useTheme", "menuitem_homepage", "menuitem_about", 
-                          "menuseparator_1", "menuitem_uninstall",
-                          "menuitem_cancelUninstall", "menuitem_update",
+                          "menuseparator_1", "menuitem_uninstall", "menuitem_update",
                           "menuitem_enable"];
 
 function buildContextMenu(aEvent)
@@ -625,14 +623,19 @@ function buildContextMenu(aEvent)
   var name = selectedItem ? selectedItem.getAttribute("name") : "";
   menuitem_about.setAttribute("label", extensionsStrings.getFormattedString("aboutExtension", [name]));
   
-  var canEnable = gExtensionsViewController.isCommandEnabled("cmd_cancelUninstall");
-  document.getElementById("menuitem_cancelUninstall_clone").hidden = !canEnable;
-  document.getElementById("menuitem_uninstall_clone").hidden = canEnable;
-
   if (isExtensions) {
-    canEnable = gExtensionsViewController.isCommandEnabled("cmd_reallyEnable");
-    document.getElementById("menuitem_enable_clone").hidden = !canEnable;
-    document.getElementById("menuitem_disable_clone").hidden = canEnable;
+    var canEnable = gExtensionsViewController.isCommandEnabled("cmd_reallyEnable");
+    var menuitemToShow, menuitemToHide;
+    if (canEnable) {
+      menuitemToShow = document.getElementById("menuitem_enable_clone");
+      menuitemToHide = document.getElementById("menuitem_disable_clone");
+    }
+    else {
+      menuitemToShow = document.getElementById("menuitem_disable_clone");
+      menuitemToHide = document.getElementById("menuitem_enable_clone");
+    }
+    menuitemToShow.hidden = false;
+    menuitemToHide.hidden = true;
   }
   else {
     var enableMenu = document.getElementById("menuitem_enable_clone");
@@ -715,7 +718,7 @@ var gExtensionsDNDObserver =
     // XXXrstrong - bug 269568, GTK2 drag and drop is returning invalid data for
     // dragenter and dragover. To workaround this we always set canDrop to true
     // and just use the xfer data returned in ondrop which is valid.
-//@line 769 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 772 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     this._canDrop = true;
   },
 
@@ -749,11 +752,8 @@ var gExtensionsDNDObserver =
     if (xpiCount > 0) 
       InstallTrigger.install(xpinstallObj);
     if (themeCount > 0) {
-      // XXXrstrong Only allow the install of one theme due to bug 257992
-      for (var fileName in themes) {
+      for (var fileName in themes)
         InstallTrigger.installChrome(InstallTrigger.SKIN, themes[fileName], fileName);
-        break;
-      }
     }
   },
   _flavourSet: null,  
@@ -834,9 +834,6 @@ var gExtensionsViewController = {
              opType != OP_NEEDS_UNINSTALL &&
              selectedItem.getAttribute("locked") != "true" &&
              canWriteToLocation(selectedItem);
-    case "cmd_cancelUninstall":
-      return selectedItem &&
-              opType == OP_NEEDS_UNINSTALL;
     case "cmd_update":
       return selectedItem &&
              selectedItem.getAttribute("updateable") != "false" &&
@@ -849,17 +846,17 @@ var gExtensionsViewController = {
       return selectedItem && 
             (selectedItem.disabled &&
              opType != OP_NEEDS_ENABLE ||
-             opType == OP_NEEDS_DISABLE);
+             opType == OP_NEEDS_DISABLE ||
+             opType == OP_NEEDS_UNINSTALL);
     case "cmd_enable":
     //controls wheter the Enable/Disable menuitem is enabled
       return selectedItem && 
-             (opType == OP_NONE ||
-             opType == OP_NEEDS_DISABLE) &&
-             selectedItem.getAttribute("satisfiesDependencies") != "false" &&
+             opType != OP_NEEDS_ENABLE &&
+             opType != OP_NEEDS_INSTALL &&
+             opType != OP_NEEDS_UPGRADE &&
              selectedItem.getAttribute("compatible") != "false";
     case "cmd_disable":
       return selectedItem &&
-            selectedItem.getAttribute("satisfiesDependencies") != "false" &&
             (opType == OP_NONE ||
              opType == OP_NEEDS_ENABLE);
     case "cmd_movetop":
@@ -869,10 +866,10 @@ var gExtensionsViewController = {
     case "cmd_movedn":
       var children = gExtensionsView.children;
       return selectedItem && (children[children.length-1] != selectedItem);
-//@line 923 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 920 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     case "cmd_install":
       return true;   
-//@line 926 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 923 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     }
     return false;
   },
@@ -938,7 +935,7 @@ var gExtensionsViewController = {
         try {
           var prefs = Components.classes["@mozilla.org/preferences-service;1"]
                                  .getService(Components.interfaces.nsIPrefBranch);
-          var instantApply = prefs.getBoolPref("browser.preferences.instantApply");
+          instantApply = prefs.getBoolPref("browser.preferences.instantApply");
           features = "chrome,titlebar,toolbar,centerscreen" + (instantApply ? ",dialog=no" : ",modal");
         }
         catch (e) {
@@ -968,9 +965,9 @@ var gExtensionsViewController = {
       if (!aSelectedItem) return;
       var aboutURL = aSelectedItem.getAttribute("aboutURL");
       if (aboutURL != "")
-        openDialog(aboutURL, "", "chrome,centerscreen,modal");
+        openDialog(aboutURL, "", "chrome,modal");
       else
-        openDialog("chrome://mozapps/content/extensions/about.xul", "", "chrome,centerscreen,modal", aSelectedItem.id, gExtensionsView.database);
+        openDialog("chrome://mozapps/content/extensions/about.xul", "", "chrome,modal", aSelectedItem.id, gExtensionsView.database);
     },  
     
     cmd_movetop: function (aSelectedItem)
@@ -1018,32 +1015,19 @@ var gExtensionsViewController = {
     {
       // Confirm the uninstall
       var extensionsStrings = document.getElementById("extensionsStrings");
+      var brandStrings = document.getElementById("brandStrings");
+
       var name = aSelectedItem.getAttribute("name");
-      var id = getIDFromResourceURI(aSelectedItem.id);
-      var dependentItems = gExtensionManager.getDependentItemListForID(id, true, { });
+      var title = extensionsStrings.getFormattedString("queryUninstallTitle", [name]);
+      if (gWindowState == "extensions")
+        var message = extensionsStrings.getFormattedString("queryUninstallExtensionMessage", [name, name]);
+      else if (gWindowState == "themes")
+        message = extensionsStrings.getFormattedString("queryUninstallThemeMessage", [name]);
 
-      if (dependentItems.length > 0)
-        var message = extensionsStrings.getFormattedString("uninstallWarningDependMessage", [name]);
-      else
-        message = extensionsStrings.getFormattedString("uninstallWarningMessage", [name]);
-
-      var params = {
-        message1: message,
-        message2: extensionsStrings.getFormattedString("uninstallQueryMessage", [name]),
-        title: extensionsStrings.getFormattedString("uninstallTitle", [name]),
-        buttons: {
-          accept: { label: extensionsStrings.getString("uninstallButton"),
-                    focused: true },
-          cancel: { label: extensionsStrings.getString("cancelButton") }
-        }
-      }
-      var names = [];
-      for (var i = 0; i < dependentItems.length; ++i)
-        names.push(dependentItems[i].name + " " + dependentItems[i].version);
-
-      window.openDialog("chrome://mozapps/content/extensions/list.xul", "", 
-                        "titlebar,modal,centerscreen", names, params);
-      if (params.result != "accept") 
+      // XXXben - improve the wording on the buttons here!
+      var promptSvc = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
+                                .getService(Components.interfaces.nsIPromptService);
+      if (!promptSvc.confirm(window, title, message))
         return;
 
       var selectedID = aSelectedItem.id;
@@ -1061,51 +1045,18 @@ var gExtensionsViewController = {
           this.cmd_useTheme(document.getElementById(PREFIX_ITEM_URI + "{972ce4c6-7e08-4474-a285-3208198ce6fd}"));
       }
       gExtensionManager.uninstallItem(getIDFromResourceURI(selectedID));
-      gExtensionsViewController.onCommandUpdate();
-    },
 
-    cmd_cancelUninstall: function (aSelectedItem)
-    {
-      gExtensionManager.cancelUninstallItem(getIDFromResourceURI(aSelectedItem.id));
-      gExtensionsViewController.onCommandUpdate();
     },
 
     cmd_disable: function (aSelectedItem)
     {
-      var id = getIDFromResourceURI(aSelectedItem.id);
-      var dependentItems = gExtensionManager.getDependentItemListForID(id, false, { });
-
-      if (dependentItems.length > 0) {
-        var extensionsStrings = document.getElementById("extensionsStrings");
-        var name = aSelectedItem.getAttribute("name");
-        var message = extensionsStrings.getFormattedString("disableWarningDependMessage", [name]);
-        var params = {
-          message1: message,
-          message2: extensionsStrings.getFormattedString("disableQueryMessage", [name]),
-          title: extensionsStrings.getFormattedString("disableTitle", [name]),
-          buttons: {
-            accept: { label: extensionsStrings.getString("disableButton"),
-                      focused: true },
-            cancel: { label: extensionsStrings.getString("cancelButton") }
-          }
-        }
-        var names = [];
-        for (var i = 0; i < dependentItems.length; ++i)
-          names.push(dependentItems[i].name + " " + dependentItems[i].version);
-
-        window.openDialog("chrome://mozapps/content/extensions/list.xul", "", 
-                          "titlebar,modal,centerscreen", names, params);
-        if (params.result != "accept") 
-          return;
-      }
-      gExtensionManager.disableItem(id);
-      gExtensionsView.selectedItem = document.getElementById(aSelectedItem.id);
+      gExtensionManager.disableItem(getIDFromResourceURI(aSelectedItem.id));
     },
     
     cmd_enable: function (aSelectedItem)
     {
       gExtensionManager.enableItem(getIDFromResourceURI(aSelectedItem.id));
-//@line 1163 "/builds/tinderbox/XR-Mozilla1.8/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
+//@line 1114 "/builds/tinderbox/XR-Mozilla1.8.0/Linux_2.4.21-32.0.1.ELsmp_Depend/mozilla/toolkit/mozapps/extensions/content/extensions.js"
     },
 
     cmd_install: function(aSelectedItem)
